summaryrefslogtreecommitdiffstats
path: root/kugar/kudesigner
diff options
context:
space:
mode:
Diffstat (limited to 'kugar/kudesigner')
-rw-r--r--kugar/kudesigner/kudesigner_doc.cpp76
-rw-r--r--kugar/kudesigner/kudesigner_doc.h27
-rw-r--r--kugar/kudesigner/kudesigner_factory.cpp14
-rw-r--r--kugar/kudesigner/kudesigner_factory.h5
-rw-r--r--kugar/kudesigner/kudesigner_view.cpp164
-rw-r--r--kugar/kudesigner/kudesigner_view.h25
-rw-r--r--kugar/kudesigner/templates/General/A0.ktm2
-rw-r--r--kugar/kudesigner/templates/General/A1.ktm2
-rw-r--r--kugar/kudesigner/templates/General/A2.ktm2
-rw-r--r--kugar/kudesigner/templates/General/A3.ktm2
-rw-r--r--kugar/kudesigner/templates/General/A4.ktm2
-rw-r--r--kugar/kudesigner/templates/General/A5.ktm2
-rw-r--r--kugar/kudesigner/templates/General/A6.ktm2
-rw-r--r--kugar/kudesigner/templates/General/A7.ktm2
-rw-r--r--kugar/kudesigner/templates/General/A8.ktm2
-rw-r--r--kugar/kudesigner/templates/General/A9.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B0.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B1.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B10.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B2.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B3.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B4.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B5.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B6.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B7.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B8.ktm2
-rw-r--r--kugar/kudesigner/templates/General/B9.ktm2
-rw-r--r--kugar/kudesigner/templates/General/C5E.ktm2
-rw-r--r--kugar/kudesigner/templates/General/Comm10E.ktm2
-rw-r--r--kugar/kudesigner/templates/General/DLE.ktm2
-rw-r--r--kugar/kudesigner/templates/General/Executive.ktm2
-rw-r--r--kugar/kudesigner/templates/General/Folio.ktm2
-rw-r--r--kugar/kudesigner/templates/General/Ledger.ktm2
-rw-r--r--kugar/kudesigner/templates/General/Legal.ktm2
-rw-r--r--kugar/kudesigner/templates/General/Letter.ktm2
-rw-r--r--kugar/kudesigner/templates/General/Tabloid.ktm2
36 files changed, 187 insertions, 184 deletions
diff --git a/kugar/kudesigner/kudesigner_doc.cpp b/kugar/kudesigner/kudesigner_doc.cpp
index eb240a88..0f554866 100644
--- a/kugar/kudesigner/kudesigner_doc.cpp
+++ b/kugar/kudesigner/kudesigner_doc.cpp
@@ -27,29 +27,29 @@
#include <kstandarddirs.h>
#include <kcommand.h>
-#include <qpainter.h>
-#include <qprinter.h>
-#include <qpaintdevicemetrics.h>
-#include <qfileinfo.h>
-#include <qdockwindow.h>
-#include <qdom.h>
-#include <qtextstream.h>
-#include <qtextcodec.h>
+#include <tqpainter.h>
+#include <tqprinter.h>
+#include <tqpaintdevicemetrics.h>
+#include <tqfileinfo.h>
+#include <tqdockwindow.h>
+#include <tqdom.h>
+#include <tqtextstream.h>
+#include <tqtextcodec.h>
#include <canvas.h>
#include <kugartemplate.h>
#include "kudesigner_view.h"
-KudesignerDoc::KudesignerDoc( QWidget *parentWidget, const char *widgetName, QObject* parent, const char* name, bool singleViewMode )
- : KoDocument( parentWidget, widgetName, parent, name, singleViewMode ), m_plugin( 0 ), m_propPos( DockRight ), m_modified( false )
+KudesignerDoc::KudesignerDoc( TQWidget *tqparentWidget, const char *widgetName, TQObject* tqparent, const char* name, bool singleViewMode )
+ : KoDocument( tqparentWidget, widgetName, tqparent, name, singleViewMode ), m_plugin( 0 ), m_propPos( DockRight ), m_modified( false )
{
setInstance( KudesignerFactory::global(), false );
setTemplateType("kudesigner_template");
history = new KoCommandHistory( actionCollection() );
- // connect( history, SIGNAL( documentRestored() ), this, SLOT( slotDocumentRestored() ) );
- // connect( history, SIGNAL( commandExecuted() ), this, SLOT( slotCommandExecuted() ) );
+ // connect( history, TQT_SIGNAL( documentRestored() ), this, TQT_SLOT( slotDocumentRestored() ) );
+ // connect( history, TQT_SIGNAL( commandExecuted() ), this, TQT_SLOT( slotCommandExecuted() ) );
docCanvas = new Kudesigner::Canvas( 100, 100 );
emit canvasChanged( docCanvas );
}
@@ -66,14 +66,14 @@ void KudesignerDoc::addCommand( KCommand *cmd )
/* history->addCommand(cmd);*/
}
-bool KudesignerDoc::initDoc( InitDocFlags flags, QWidget* parentWidget )
+bool KudesignerDoc::initDoc( InitDocFlags flags, TQWidget* tqparentWidget )
{
// If nothing is loaded, do initialize here
bool ok = FALSE;
// TODO if (flags==KoDocument::InitDocEmpty)
- QString file;
+ TQString file;
KoTemplateChooseDia::DialogType dlgtype;
if ( flags != KoDocument::InitDocFileNew )
dlgtype = KoTemplateChooseDia::Everything;
@@ -82,7 +82,7 @@ bool KudesignerDoc::initDoc( InitDocFlags flags, QWidget* parentWidget )
KoTemplateChooseDia::ReturnType ret = KoTemplateChooseDia::choose(
KudesignerFactory::global(), file,
- dlgtype, "kudesigner_template", parentWidget );
+ dlgtype, "kudesigner_template", tqparentWidget );
if ( ret == KoTemplateChooseDia::Template )
{
resetURL();
@@ -98,7 +98,7 @@ bool KudesignerDoc::initDoc( InitDocFlags flags, QWidget* parentWidget )
}
else if ( ret == KoTemplateChooseDia::Empty )
{
- QString fileName( locate( "kudesigner_template", "General/.source/A4.ktm", KudesignerFactory::global() ) );
+ TQString fileName( locate( "kudesigner_template", "General/.source/A4.ktm", KudesignerFactory::global() ) );
resetURL();
ok = loadNativeFormat( fileName );
if ( !ok )
@@ -112,7 +112,7 @@ bool KudesignerDoc::initDoc( InitDocFlags flags, QWidget* parentWidget )
void KudesignerDoc::initEmpty()
{
- QString fileName( locate( "kudesigner_template", "General/.source/A4.ktm", KudesignerFactory::global() ) );
+ TQString fileName( locate( "kudesigner_template", "General/.source/A4.ktm", KudesignerFactory::global() ) );
bool ok = loadNativeFormat( fileName );
if ( !ok )
showLoadingErrorDialog();
@@ -121,12 +121,12 @@ void KudesignerDoc::initEmpty()
setModified(false);
}
-KoView* KudesignerDoc::createViewInstance( QWidget* parent, const char* name )
+KoView* KudesignerDoc::createViewInstance( TQWidget* tqparent, const char* name )
{
- return new KudesignerView( this, parent, name );
+ return new KudesignerView( this, tqparent, name );
}
-bool KudesignerDoc::loadOasis( const QDomDocument&, KoOasisStyles&, const QDomDocument&, KoStore* )
+bool KudesignerDoc::loadOasis( const TQDomDocument&, KoOasisStyles&, const TQDomDocument&, KoStore* )
{
return false;
}
@@ -136,7 +136,7 @@ bool KudesignerDoc::saveOasis( KoStore*, KoXmlWriter* )
return false;
}
-void KudesignerDoc::paintContent( QPainter& painter, const QRect& rect, bool /*transparent*/,
+void KudesignerDoc::paintContent( TQPainter& painter, const TQRect& rect, bool /*transparent*/,
double /*zoomX*/, double /*zoomY*/ )
{
// ####### handle transparency
@@ -167,22 +167,22 @@ int KudesignerDoc::supportedSpecialFormats() const
return SaveAsDirectoryStore | SaveAsFlatXML;
}
-QDomDocument KudesignerDoc::saveXML()
+TQDomDocument KudesignerDoc::saveXML()
{
- QDomDocument doc;
+ TQDomDocument doc;
doc.setContent( docCanvas->kugarTemplate() ->getXml() );
return doc;
}
-bool KudesignerDoc::saveToStream( QIODevice * dev )
+bool KudesignerDoc::saveToStream( TQIODevice * dev )
{
- QTextStream ts( dev );
- ts.setCodec( QTextCodec::codecForName( "UTF-8" ) );
+ TQTextStream ts( dev );
+ ts.setCodec( TQTextCodec::codecForName( "UTF-8" ) );
ts << docCanvas->kugarTemplate() ->getXml();
return true;
}
-void KudesignerDoc::loadPlugin( const QString &name )
+void KudesignerDoc::loadPlugin( const TQString &name )
{
kdDebug() << "Trying to load plugin: " << name << endl;
KuDesignerPlugin *plug = KParts::ComponentFactory::createInstanceFromLibrary<KuDesignerPlugin>( name.utf8(), this );
@@ -212,7 +212,7 @@ KuDesignerPlugin *KudesignerDoc::plugin()
return canvas() ->plugin();
}
-Qt::Dock KudesignerDoc::propertyPosition()
+TQt::Dock KudesignerDoc::propertyPosition()
{
return m_propPos;
}
@@ -233,10 +233,10 @@ bool KudesignerDoc::modified( ) const
return m_modified;
}
-bool KudesignerDoc::loadXML( QIODevice *, const QDomDocument &rt )
+bool KudesignerDoc::loadXML( TQIODevice *, const TQDomDocument &rt )
{
- QDomNode report, rep;
- for ( QDomNode report = rt.firstChild(); !report.isNull(); report = report.nextSibling() )
+ TQDomNode report, rep;
+ for ( TQDomNode report = rt.firstChild(); !report.isNull(); report = report.nextSibling() )
{
if ( report.nodeName() == "KugarTemplate" )
{
@@ -246,12 +246,12 @@ bool KudesignerDoc::loadXML( QIODevice *, const QDomDocument &rt )
}
report = rep;
- QDomNamedNodeMap attributes = report.attributes();
+ TQDomNamedNodeMap attributes = report.attributes();
//getting the page width and height
int height = 297;
int width = 210;
- if ( attributes.namedItem( "PageOrientation" ).nodeValue().toInt() )
+ if ( attributes.namedItem( "PageQt::Orientation" ).nodeValue().toInt() )
{
int temp = height;
height = width;
@@ -259,16 +259,16 @@ bool KudesignerDoc::loadXML( QIODevice *, const QDomDocument &rt )
}
//zooming canvas according to screen resolution
- QPrinter* printer;
+ TQPrinter* printer;
// Set the page size
- printer = new QPrinter();
+ printer = new TQPrinter();
printer->setFullPage( true );
- printer->setPageSize( ( QPrinter::PageSize ) attributes.namedItem( "PageSize" ).nodeValue().toInt() );
- printer->setOrientation( ( QPrinter::Orientation ) attributes.namedItem( "PageOrientation" ).nodeValue().toInt() );
+ printer->setPageSize( ( TQPrinter::PageSize ) attributes.namedItem( "PageSize" ).nodeValue().toInt() );
+ printer->setOrientation( ( TQPrinter::Orientation ) attributes.namedItem( "PageQt::Orientation" ).nodeValue().toInt() );
// Get the page metrics and set appropriate wigth and height
- QPaintDeviceMetrics pdm( printer );
+ TQPaintDeviceMetrics pdm( printer );
width = pdm.width();
height = pdm.height();
diff --git a/kugar/kudesigner/kudesigner_doc.h b/kugar/kudesigner/kudesigner_doc.h
index 71fdde3c..318876d2 100644
--- a/kugar/kudesigner/kudesigner_doc.h
+++ b/kugar/kudesigner/kudesigner_doc.h
@@ -24,10 +24,10 @@
#include <KoCommandHistory.h>
#include "plugin.h"
-class QCanvas;
-class QDomNode;
-class QIODevice;
-class QDomDocument;
+class TQCanvas;
+class TQDomNode;
+class TQIODevice;
+class TQDomDocument;
namespace Kudesigner
{
@@ -37,27 +37,28 @@ class Canvas;
class KudesignerDoc: public KoDocument
{
Q_OBJECT
+ TQ_OBJECT
public:
- KudesignerDoc( QWidget *parentWidget = 0, const char *widgetName = 0, QObject* parent = 0, const char* name = 0, bool singleViewMode = false );
+ KudesignerDoc( TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject* tqparent = 0, const char* name = 0, bool singleViewMode = false );
~KudesignerDoc();
- virtual void paintContent( QPainter& painter, const QRect& rect, bool transparent = FALSE, double zoomX = 1.0, double zoomY = 1.0 );
+ virtual void paintContent( TQPainter& painter, const TQRect& rect, bool transparent = FALSE, double zoomX = 1.0, double zoomY = 1.0 );
- virtual bool initDoc( InitDocFlags flags, QWidget* parentWidget );
+ virtual bool initDoc( InitDocFlags flags, TQWidget* tqparentWidget );
- virtual bool loadOasis( const QDomDocument&, KoOasisStyles&, const QDomDocument&, KoStore* );
+ virtual bool loadOasis( const TQDomDocument&, KoOasisStyles&, const TQDomDocument&, KoStore* );
virtual bool saveOasis( KoStore*, KoXmlWriter* );
- virtual bool loadXML( QIODevice *, const QDomDocument & );
- virtual QDomDocument saveXML();
+ virtual bool loadXML( TQIODevice *, const TQDomDocument & );
+ virtual TQDomDocument saveXML();
virtual int supportedSpecialFormats() const;
- virtual bool saveToStream( QIODevice * dev );
+ virtual bool saveToStream( TQIODevice * dev );
Kudesigner::Canvas *canvas();
- void loadPlugin( const QString& name );
+ void loadPlugin( const TQString& name );
KuDesignerPlugin *plugin();
Dock propertyPosition();
void setForcedPropertyEditorPosition( Dock );
@@ -76,7 +77,7 @@ public slots:
virtual void initEmpty();
protected:
- virtual KoView* createViewInstance( QWidget* parent, const char* name );
+ virtual KoView* createViewInstance( TQWidget* tqparent, const char* name );
virtual bool completeSaving( KoStore* store );
virtual bool completeLoading( KoStore* store );
diff --git a/kugar/kudesigner/kudesigner_factory.h b/kugar/kudesigner/kudesigner_factory.h
index ae660eb5..82eb7bb8 100644
--- a/kugar/kudesigner/kudesigner_factory.h
+++ b/kugar/kudesigner/kudesigner_factory.h
@@ -28,11 +28,12 @@ class KAboutData;
class KUGARDESIGNER_EXPORT KudesignerFactory : public KoFactory
{
Q_OBJECT
+ TQ_OBJECT
public:
- KudesignerFactory( QObject* parent = 0, const char* name = 0 );
+ KudesignerFactory( TQObject* tqparent = 0, const char* name = 0 );
~KudesignerFactory();
- virtual KParts::Part *createPartObject( QWidget *parentWidget = 0, const char *widgetName = 0, QObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const QStringList &args = QStringList() );
+ virtual KParts::Part *createPartObject( TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject *tqparent = 0, const char *name = 0, const char *classname = "KoDocument", const TQStringList &args = TQStringList() );
static KInstance* global();
diff --git a/kugar/kudesigner/kudesigner_view.cpp b/kugar/kudesigner/kudesigner_view.cpp
index 713b8521..4533813d 100644
--- a/kugar/kudesigner/kudesigner_view.cpp
+++ b/kugar/kudesigner/kudesigner_view.cpp
@@ -22,18 +22,18 @@
#include <map>
-#include <qpainter.h>
-#include <qiconset.h>
-#include <qinputdialog.h>
-#include <qevent.h>
-#include <qmainwindow.h>
-#include <qaction.h>
-#include <qlayout.h>
-#include <qdockwindow.h>
-#include <qmenubar.h>
-#include <qmessagebox.h>
-#include <qspinbox.h>
-#include <qlabel.h>
+#include <tqpainter.h>
+#include <tqiconset.h>
+#include <tqinputdialog.h>
+#include <tqevent.h>
+#include <tqmainwindow.h>
+#include <tqaction.h>
+#include <tqlayout.h>
+#include <tqdockwindow.h>
+#include <tqmenubar.h>
+#include <tqmessagebox.h>
+#include <tqspinbox.h>
+#include <tqlabel.h>
#include <kaction.h>
#include <kstdaction.h>
@@ -68,8 +68,8 @@
using namespace Kudesigner;
-KudesignerView::KudesignerView( KudesignerDoc* part, QWidget* parent, const char* name )
- : KoView( part, parent, name ), m_propertyEditor( 0 ), m_doc( part )
+KudesignerView::KudesignerView( KudesignerDoc* part, TQWidget* tqparent, const char* name )
+ : KoView( part, tqparent, name ), m_propertyEditor( 0 ), m_doc( part )
{
setInstance( KudesignerFactory::global() );
if ( !part->isReadWrite() ) // readonly case, e.g. when embedded into konqueror
@@ -77,7 +77,7 @@ KudesignerView::KudesignerView( KudesignerDoc* part, QWidget* parent, const char
else
setXMLFile( "kudesignerui.rc" );
- QVBoxLayout *l = new QVBoxLayout( this, 0, 0 );
+ TQVBoxLayout *l = new TQVBoxLayout( this, 0, 0 );
m_view = new Kudesigner::View( part->canvas(), this );
if ( part->plugin() )
{
@@ -88,13 +88,13 @@ KudesignerView::KudesignerView( KudesignerDoc* part, QWidget* parent, const char
l->addWidget( m_view );
m_view->viewport() ->setFocusProxy( m_view );
- m_view->viewport() ->setFocusPolicy( WheelFocus );
+ m_view->viewport() ->setFocusPolicy( TQ_WheelFocus );
m_view->setFocus();
m_view->itemToInsert = 0;
- QDockWindow *dw1 = new QDockWindow( QDockWindow::OutsideDock, shell() );
- QDockWindow *dw2 = new QDockWindow( QDockWindow::OutsideDock, shell() );
+ TQDockWindow *dw1 = new TQDockWindow( TQDockWindow::OutsideDock, shell() );
+ TQDockWindow *dw2 = new TQDockWindow( TQDockWindow::OutsideDock, shell() );
m_structure = new Kudesigner::StructureWidget( dw1 );
m_propertyEditor = new Editor( dw2 );
dw1->boxLayout() ->addWidget( m_structure, 1 );
@@ -106,8 +106,8 @@ KudesignerView::KudesignerView( KudesignerDoc* part, QWidget* parent, const char
if ( m_doc->plugin() )
{
- // connect( m_propertyEditor, SIGNAL(createPluggedInEditor(QWidget*&, Editor *, Property*, Box *)),
- // m_doc->plugin(), SLOT(createPluggedInEditor(QWidget*&, Editor *, Property*, Box *)));
+ // connect( m_propertyEditor, TQT_SIGNAL(createPluggedInEditor(TQWidget*&, Editor *, Property*, Box *)),
+ // m_doc->plugin(), TQT_SLOT(createPluggedInEditor(TQWidget*&, Editor *, Property*, Box *)));
kdDebug() << "*************Property and plugin have been connected" << endl;
}
@@ -117,33 +117,33 @@ KudesignerView::KudesignerView( KudesignerDoc* part, QWidget* parent, const char
m_structure->setDocument( m_doc->canvas() );
- connect( m_doc, SIGNAL( canvasChanged( Kudesigner::Canvas * ) ),
- m_structure, SLOT( setDocument( Kudesigner::Canvas * ) ) );
- connect( m_doc->canvas(), SIGNAL( structureModified() ),
- m_structure, SLOT( refresh() ) );
+ connect( m_doc, TQT_SIGNAL( canvasChanged( Kudesigner::Canvas * ) ),
+ m_structure, TQT_SLOT( setDocument( Kudesigner::Canvas * ) ) );
+ connect( m_doc->canvas(), TQT_SIGNAL( structureModified() ),
+ m_structure, TQT_SLOT( refresh() ) );
- connect( m_view, SIGNAL( selectionMade( Buffer* ) ),
- this, SLOT( populateProperties( Buffer* ) ) );
+ connect( m_view, TQT_SIGNAL( selectionMade( Buffer* ) ),
+ this, TQT_SLOT( populateProperties( Buffer* ) ) );
- connect( m_view, SIGNAL( selectionClear() ),
- m_propertyEditor, SLOT( clear() ) );
+ connect( m_view, TQT_SIGNAL( selectionClear() ),
+ m_propertyEditor, TQT_SLOT( clear() ) );
- connect( m_view, SIGNAL( changed() ),
- m_doc, SLOT( setModified() ) );
+ connect( m_view, TQT_SIGNAL( changed() ),
+ m_doc, TQT_SLOT( setModified() ) );
- connect( m_view, SIGNAL( selectionMade( Buffer* ) ),
- m_structure, SLOT( selectionMade() ) );
- connect( m_view, SIGNAL( selectionClear() ),
- m_structure, SLOT( selectionClear() ) );
+ connect( m_view, TQT_SIGNAL( selectionMade( Buffer* ) ),
+ m_structure, TQT_SLOT( selectionMade() ) );
+ connect( m_view, TQT_SIGNAL( selectionClear() ),
+ m_structure, TQT_SLOT( selectionClear() ) );
- connect( m_view, SIGNAL( selectedActionProcessed() ), this, SLOT( unselectItemAction() ) );
- connect( m_view, SIGNAL( modificationPerformed() ), part, SLOT( setModified() ) );
- connect( m_view, SIGNAL( itemPlaced( int, int, int, int ) ), this, SLOT( placeItem( int, int, int, int ) ) );
+ connect( m_view, TQT_SIGNAL( selectedActionProcessed() ), this, TQT_SLOT( unselectItemAction() ) );
+ connect( m_view, TQT_SIGNAL( modificationPerformed() ), part, TQT_SLOT( setModified() ) );
+ connect( m_view, TQT_SIGNAL( itemPlaced( int, int, int, int ) ), this, TQT_SLOT( placeItem( int, int, int, int ) ) );
- gridLabel = new QLabel( i18n( "Grid size:" ), shell() );
- gridBox = new QSpinBox( 1, 100, 1, shell() );
+ gridLabel = new TQLabel( i18n( "Grid size:" ), shell() );
+ gridBox = new TQSpinBox( 1, 100, 1, shell() );
gridBox->setValue( 10 );
- connect( gridBox, SIGNAL( valueChanged( int ) ), m_view, SLOT( setGridSize( int ) ) );
+ connect( gridBox, TQT_SIGNAL( valueChanged( int ) ), m_view, TQT_SLOT( setGridSize( int ) ) );
initActions();
@@ -158,9 +158,9 @@ KudesignerView::~KudesignerView()
delete gridBox;
}
-void KudesignerView::paintEvent( QPaintEvent* ev )
+void KudesignerView::paintEvent( TQPaintEvent* ev )
{
- QPainter painter;
+ TQPainter painter;
painter.begin( this );
// ### TODO: Scaling
@@ -171,63 +171,63 @@ void KudesignerView::paintEvent( QPaintEvent* ev )
painter.end();
}
-void KudesignerView::resizeEvent( QResizeEvent* /*_ev*/ )
+void KudesignerView::resizeEvent( TQResizeEvent* /*_ev*/ )
{
m_view->setGeometry( 0, 0, width(), height() );
}
void KudesignerView::initActions()
{
- cutAction = KStdAction::cut( this, SLOT( cut() ), actionCollection() );
- copyAction = KStdAction::copy( this, SLOT( copy() ), actionCollection() );
- pasteAction = KStdAction::paste( this, SLOT( paste() ), actionCollection() );
- selectAllAction = KStdAction::selectAll( this, SLOT( selectAll() ), actionCollection() );
- deleteAction = new KAction( i18n( "Delete" ), "editdelete", 0, this,
- SLOT( deleteItems() ), actionCollection(), "edit_delete" );
+ cutAction = KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT( cut() ), actionCollection() );
+ copyAction = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT( copy() ), actionCollection() );
+ pasteAction = KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT( paste() ), actionCollection() );
+ selectAllAction = KStdAction::selectAll( TQT_TQOBJECT(this), TQT_SLOT( selectAll() ), actionCollection() );
+ deleteAction = new KAction( i18n( "Delete" ), "editdelete", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( deleteItems() ), actionCollection(), "edit_delete" );
cutAction->setEnabled( false );
copyAction->setEnabled( false );
pasteAction->setEnabled( false );
// deleteAction->setEnabled(false);
- sectionsReportHeader = new KAction( i18n( "Report Header" ), "irh", 0, this,
- SLOT( slotAddReportHeader() ), actionCollection(), "rheader" );
- sectionsReportFooter = new KAction( i18n( "Report Footer" ), "irf", 0, this,
- SLOT( slotAddReportFooter() ), actionCollection(), "rfooter" );
- sectionsPageHeader = new KAction( i18n( "Page Header" ), "iph", 0, this,
- SLOT( slotAddPageHeader() ), actionCollection(), "pheader" );
- sectionsPageFooter = new KAction( i18n( "Page Footer" ), "ipf", 0, this,
- SLOT( slotAddPageFooter() ), actionCollection(), "pfooter" );
- sectionsDetailHeader = new KAction( i18n( "Detail Header" ), "idh", 0, this,
- SLOT( slotAddDetailHeader() ), actionCollection(), "dheader" );
- sectionsDetail = new KAction( i18n( "Detail" ), "id", 0, this,
- SLOT( slotAddDetail() ), actionCollection(), "detail" );
- sectionsDetailFooter = new KAction( i18n( "Detail Footer" ), "idf", 0, this,
- SLOT( slotAddDetailFooter() ), actionCollection(), "dfooter" );
-
- itemsNothing = new KRadioAction( i18n( "Clear Selection" ), "frame_edit", 0, this,
- SLOT( slotAddItemNothing() ), actionCollection(), "nothing" );
+ sectionsReportHeader = new KAction( i18n( "Report Header" ), "irh", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddReportHeader() ), actionCollection(), "rheader" );
+ sectionsReportFooter = new KAction( i18n( "Report Footer" ), "irf", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddReportFooter() ), actionCollection(), "rfooter" );
+ sectionsPageHeader = new KAction( i18n( "Page Header" ), "iph", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddPageHeader() ), actionCollection(), "pheader" );
+ sectionsPageFooter = new KAction( i18n( "Page Footer" ), "ipf", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddPageFooter() ), actionCollection(), "pfooter" );
+ sectionsDetailHeader = new KAction( i18n( "Detail Header" ), "idh", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddDetailHeader() ), actionCollection(), "dheader" );
+ sectionsDetail = new KAction( i18n( "Detail" ), "id", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddDetail() ), actionCollection(), "detail" );
+ sectionsDetailFooter = new KAction( i18n( "Detail Footer" ), "idf", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddDetailFooter() ), actionCollection(), "dfooter" );
+
+ itemsNothing = new KRadioAction( i18n( "Clear Selection" ), "frame_edit", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddItemNothing() ), actionCollection(), "nothing" );
itemsNothing->setExclusiveGroup( "itemsToolBar" );
itemsNothing->setChecked( true );
- itemsLabel = new KRadioAction( i18n( "Label" ), "frame_text", 0, this,
- SLOT( slotAddItemLabel() ), actionCollection(), "label" );
+ itemsLabel = new KRadioAction( i18n( "Label" ), "frame_text", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddItemLabel() ), actionCollection(), "label" );
itemsLabel->setExclusiveGroup( "itemsToolBar" );
- itemsField = new KRadioAction( i18n( "Field" ), "frame_field", 0, this,
- SLOT( slotAddItemField() ), actionCollection(), "field" );
+ itemsField = new KRadioAction( i18n( "Field" ), "frame_field", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddItemField() ), actionCollection(), "field" );
itemsField->setExclusiveGroup( "itemsToolBar" );
- itemsSpecial = new KRadioAction( i18n( "Special Field" ), "frame_query", 0, this,
- SLOT( slotAddItemSpecial() ), actionCollection(), "special" );
+ itemsSpecial = new KRadioAction( i18n( "Special Field" ), "frame_query", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddItemSpecial() ), actionCollection(), "special" );
itemsSpecial->setExclusiveGroup( "itemsToolBar" );
- itemsCalculated = new KRadioAction( i18n( "Calculated Field" ), "frame_formula", 0, this,
- SLOT( slotAddItemCalculated() ), actionCollection(), "calcfield" );
+ itemsCalculated = new KRadioAction( i18n( "Calculated Field" ), "frame_formula", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddItemCalculated() ), actionCollection(), "calcfield" );
itemsCalculated->setExclusiveGroup( "itemsToolBar" );
- itemsLine = new KRadioAction( i18n( "Line" ), "frame_chart", 0, this,
- SLOT( slotAddItemLine() ), actionCollection(), "line" );
+ itemsLine = new KRadioAction( i18n( "Line" ), "frame_chart", 0, TQT_TQOBJECT(this),
+ TQT_SLOT( slotAddItemLine() ), actionCollection(), "line" );
itemsLine->setExclusiveGroup( "itemsToolBar" );
- gridActionLabel = new KWidgetAction( gridLabel, i18n( "Grid Label" ), 0, this,
+ gridActionLabel = new KWidgetAction( gridLabel, i18n( "Grid Label" ), 0, TQT_TQOBJECT(this),
0, actionCollection(), "gridlabel" );
- gridAction = new KWidgetAction( gridBox, i18n( "Grid Size" ), 0, this,
+ gridAction = new KWidgetAction( gridBox, i18n( "Grid Size" ), 0, TQT_TQOBJECT(this),
0, actionCollection(), "gridaction" );
}
@@ -246,7 +246,7 @@ void KudesignerView::guiActivateEvent( KParts::GUIActivateEvent *ev )
void KudesignerView::populateProperties( Buffer *buf )
{
- connect( buf, SIGNAL( propertyChanged() ), m_doc->canvas(), SLOT( changed() ) );
+ connect( buf, TQT_SIGNAL( propertyChanged() ), m_doc->canvas(), TQT_SLOT( changed() ) );
m_propertyEditor->changeSet( buf );
}
@@ -309,7 +309,7 @@ void KudesignerView::slotAddPageFooter()
void KudesignerView::slotAddDetailHeader()
{
bool Ok = false;
- unsigned int level = QInputDialog::getInteger( tr( "Add Detail Header" ), tr( "Enter detail level:" ),
+ unsigned int level = TQInputDialog::getInteger( tr( "Add Detail Header" ), tr( "Enter detail level:" ),
0, 0, 100, 1, &Ok, this );
if ( !Ok )
return ;
@@ -322,7 +322,7 @@ void KudesignerView::slotAddDetailHeader()
void KudesignerView::slotAddDetail()
{
bool Ok = false;
- unsigned int level = QInputDialog::getInteger( tr( "Add Detail" ), tr( "Enter detail level:" ),
+ unsigned int level = TQInputDialog::getInteger( tr( "Add Detail" ), tr( "Enter detail level:" ),
0, 0, 100, 1, &Ok, this );
if ( !Ok )
return ;
@@ -336,7 +336,7 @@ void KudesignerView::slotAddDetail()
void KudesignerView::slotAddDetailFooter()
{
bool Ok = false;
- unsigned int level = QInputDialog::getInteger( tr( "Add Detail Footer" ), tr( "Enter detail level:" ),
+ unsigned int level = TQInputDialog::getInteger( tr( "Add Detail Footer" ), tr( "Enter detail level:" ),
0, 0, 100, 1, &Ok, this );
if ( !Ok )
return ;
diff --git a/kugar/kudesigner/kudesigner_view.h b/kugar/kudesigner/kudesigner_view.h
index e2cd9ed0..2b1cc752 100644
--- a/kugar/kudesigner/kudesigner_view.h
+++ b/kugar/kudesigner/kudesigner_view.h
@@ -22,16 +22,16 @@
#include <KoView.h>
#include <kparts/event.h>
-#include <qdom.h>
+#include <tqdom.h>
#include <set>
-class QLabel;
-class QSpinBox;
-class QAction;
-class QPaintEvent;
-class QDockWindow;
-class QToolBar;
+class TQLabel;
+class TQSpinBox;
+class TQAction;
+class TQPaintEvent;
+class TQDockWindow;
+class TQToolBar;
class KAction;
class KRadioAction;
@@ -57,10 +57,11 @@ class ReportItem;
class KudesignerView: public KoView
{
Q_OBJECT
+ TQ_OBJECT
friend class Kudesigner::View;
public:
- KudesignerView( KudesignerDoc* part, QWidget* parent = 0, const char* name = 0 );
+ KudesignerView( KudesignerDoc* part, TQWidget* tqparent = 0, const char* name = 0 );
virtual ~KudesignerView();
Kudesigner::View *view()
@@ -94,8 +95,8 @@ protected slots:
protected:
void initActions();
- void paintEvent( QPaintEvent* );
- virtual void resizeEvent( QResizeEvent* _ev );
+ void paintEvent( TQPaintEvent* );
+ virtual void resizeEvent( TQResizeEvent* _ev );
virtual void updateReadWrite( bool readwrite );
virtual void guiActivateEvent( KParts::GUIActivateEvent *ev );
@@ -130,8 +131,8 @@ private:
KWidgetAction *gridActionLabel;
KWidgetAction *gridAction;
- QLabel *gridLabel;
- QSpinBox *gridBox;
+ TQLabel *gridLabel;
+ TQSpinBox *gridBox;
KActionCollection *itemsCollection;
KActionCollection *sectionsCollection;
diff --git a/kugar/kudesigner/templates/General/A0.ktm b/kugar/kudesigner/templates/General/A0.ktm
index 6831e87a..57f11a01 100644
--- a/kugar/kudesigner/templates/General/A0.ktm
+++ b/kugar/kudesigner/templates/General/A0.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="5" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="5" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/A1.ktm b/kugar/kudesigner/templates/General/A1.ktm
index 908b2f03..27584722 100644
--- a/kugar/kudesigner/templates/General/A1.ktm
+++ b/kugar/kudesigner/templates/General/A1.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="6" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="6" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/A2.ktm b/kugar/kudesigner/templates/General/A2.ktm
index 4ce84d05..b9ebbed9 100644
--- a/kugar/kudesigner/templates/General/A2.ktm
+++ b/kugar/kudesigner/templates/General/A2.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="7" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="7" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/A3.ktm b/kugar/kudesigner/templates/General/A3.ktm
index 725e7ef6..b5ac9141 100644
--- a/kugar/kudesigner/templates/General/A3.ktm
+++ b/kugar/kudesigner/templates/General/A3.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="8" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="8" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/A4.ktm b/kugar/kudesigner/templates/General/A4.ktm
index 17c2ff4e..cd0c17cc 100644
--- a/kugar/kudesigner/templates/General/A4.ktm
+++ b/kugar/kudesigner/templates/General/A4.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="0" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="0" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/A5.ktm b/kugar/kudesigner/templates/General/A5.ktm
index 64b65b52..133810fb 100644
--- a/kugar/kudesigner/templates/General/A5.ktm
+++ b/kugar/kudesigner/templates/General/A5.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="9" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="9" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/A6.ktm b/kugar/kudesigner/templates/General/A6.ktm
index e69da18e..7aac1ea7 100644
--- a/kugar/kudesigner/templates/General/A6.ktm
+++ b/kugar/kudesigner/templates/General/A6.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="10" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="10" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/A7.ktm b/kugar/kudesigner/templates/General/A7.ktm
index c62e8489..6e93cc62 100644
--- a/kugar/kudesigner/templates/General/A7.ktm
+++ b/kugar/kudesigner/templates/General/A7.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="11" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="11" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/A8.ktm b/kugar/kudesigner/templates/General/A8.ktm
index 6cbd58d4..60a87b5b 100644
--- a/kugar/kudesigner/templates/General/A8.ktm
+++ b/kugar/kudesigner/templates/General/A8.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="12" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="12" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/A9.ktm b/kugar/kudesigner/templates/General/A9.ktm
index f819153f..4f9c7702 100644
--- a/kugar/kudesigner/templates/General/A9.ktm
+++ b/kugar/kudesigner/templates/General/A9.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="13" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="13" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B0.ktm b/kugar/kudesigner/templates/General/B0.ktm
index 93bb7e00..17e60661 100644
--- a/kugar/kudesigner/templates/General/B0.ktm
+++ b/kugar/kudesigner/templates/General/B0.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="14" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="14" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B1.ktm b/kugar/kudesigner/templates/General/B1.ktm
index 00512408..0aebed02 100644
--- a/kugar/kudesigner/templates/General/B1.ktm
+++ b/kugar/kudesigner/templates/General/B1.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="15" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="15" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B10.ktm b/kugar/kudesigner/templates/General/B10.ktm
index 99070c77..24b561c7 100644
--- a/kugar/kudesigner/templates/General/B10.ktm
+++ b/kugar/kudesigner/templates/General/B10.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="16" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="16" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B2.ktm b/kugar/kudesigner/templates/General/B2.ktm
index c31af4ce..f8de9304 100644
--- a/kugar/kudesigner/templates/General/B2.ktm
+++ b/kugar/kudesigner/templates/General/B2.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="17" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="17" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B3.ktm b/kugar/kudesigner/templates/General/B3.ktm
index 31bf80db..8b8608d8 100644
--- a/kugar/kudesigner/templates/General/B3.ktm
+++ b/kugar/kudesigner/templates/General/B3.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="18" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="18" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B4.ktm b/kugar/kudesigner/templates/General/B4.ktm
index aeac2cfa..f954c76f 100644
--- a/kugar/kudesigner/templates/General/B4.ktm
+++ b/kugar/kudesigner/templates/General/B4.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="19" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="19" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B5.ktm b/kugar/kudesigner/templates/General/B5.ktm
index 9de7d62b..d57ce02d 100644
--- a/kugar/kudesigner/templates/General/B5.ktm
+++ b/kugar/kudesigner/templates/General/B5.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="1" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="1" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B6.ktm b/kugar/kudesigner/templates/General/B6.ktm
index 48e21a22..fc7525a4 100644
--- a/kugar/kudesigner/templates/General/B6.ktm
+++ b/kugar/kudesigner/templates/General/B6.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="20" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="20" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B7.ktm b/kugar/kudesigner/templates/General/B7.ktm
index 61e59b66..9255b34f 100644
--- a/kugar/kudesigner/templates/General/B7.ktm
+++ b/kugar/kudesigner/templates/General/B7.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="21" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="21" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B8.ktm b/kugar/kudesigner/templates/General/B8.ktm
index b7fb2b57..448cd402 100644
--- a/kugar/kudesigner/templates/General/B8.ktm
+++ b/kugar/kudesigner/templates/General/B8.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="22" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="22" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/B9.ktm b/kugar/kudesigner/templates/General/B9.ktm
index 5c71ef55..671b5631 100644
--- a/kugar/kudesigner/templates/General/B9.ktm
+++ b/kugar/kudesigner/templates/General/B9.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="23" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="23" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/C5E.ktm b/kugar/kudesigner/templates/General/C5E.ktm
index 5d120ec3..34c91c46 100644
--- a/kugar/kudesigner/templates/General/C5E.ktm
+++ b/kugar/kudesigner/templates/General/C5E.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="24" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="24" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/Comm10E.ktm b/kugar/kudesigner/templates/General/Comm10E.ktm
index 7a6e512e..c73c9f49 100644
--- a/kugar/kudesigner/templates/General/Comm10E.ktm
+++ b/kugar/kudesigner/templates/General/Comm10E.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="25" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="25" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/DLE.ktm b/kugar/kudesigner/templates/General/DLE.ktm
index 66875800..ea217fad 100644
--- a/kugar/kudesigner/templates/General/DLE.ktm
+++ b/kugar/kudesigner/templates/General/DLE.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="26" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="26" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/Executive.ktm b/kugar/kudesigner/templates/General/Executive.ktm
index 9fe71873..e5b08181 100644
--- a/kugar/kudesigner/templates/General/Executive.ktm
+++ b/kugar/kudesigner/templates/General/Executive.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="4" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="4" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/Folio.ktm b/kugar/kudesigner/templates/General/Folio.ktm
index 832a1d59..32a7b7fc 100644
--- a/kugar/kudesigner/templates/General/Folio.ktm
+++ b/kugar/kudesigner/templates/General/Folio.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="27" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="27" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/Ledger.ktm b/kugar/kudesigner/templates/General/Ledger.ktm
index db605f13..34e7fad2 100644
--- a/kugar/kudesigner/templates/General/Ledger.ktm
+++ b/kugar/kudesigner/templates/General/Ledger.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="28" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="28" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/Legal.ktm b/kugar/kudesigner/templates/General/Legal.ktm
index 85953bb8..0edb0446 100644
--- a/kugar/kudesigner/templates/General/Legal.ktm
+++ b/kugar/kudesigner/templates/General/Legal.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="3" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="3" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/Letter.ktm b/kugar/kudesigner/templates/General/Letter.ktm
index d6838210..cd0047eb 100644
--- a/kugar/kudesigner/templates/General/Letter.ktm
+++ b/kugar/kudesigner/templates/General/Letter.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="2" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="2" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/templates/General/Tabloid.ktm b/kugar/kudesigner/templates/General/Tabloid.ktm
index 5bccc107..f22445d4 100644
--- a/kugar/kudesigner/templates/General/Tabloid.ktm
+++ b/kugar/kudesigner/templates/General/Tabloid.ktm
@@ -2,7 +2,7 @@
<!DOCTYPE KugarTemplate SYSTEM "kugartemplate.dtd">
-<KugarTemplate PageSize="29" PageOrientation="0" TopMargin="20"
+<KugarTemplate PageSize="29" PageQt::Orientation="0" TopMargin="20"
BottomMargin="20" LeftMargin="20" RightMargin="20">
</KugarTemplate>
diff --git a/kugar/kudesigner/kudesigner_factory.cpp b/kugar/kudesigner/kudesigner_factory.cpp
index c83cedbf..2c90d1d8 100644
--- a/kugar/kudesigner/kudesigner_factory.cpp
+++ b/kugar/kudesigner/kudesigner_factory.cpp
@@ -29,8 +29,8 @@
KInstance* KudesignerFactory::s_global = 0L;
KAboutData* KudesignerFactory::s_aboutData = 0L;
-KudesignerFactory::KudesignerFactory( QObject* parent, const char* name )
- : KoFactory( parent, name )
+KudesignerFactory::KudesignerFactory( TQObject* tqparent, const char* name )
+ : KoFactory( tqparent, name )
{
global();
}
@@ -43,20 +43,20 @@ KudesignerFactory::~KudesignerFactory()
s_global = 0L;
}
-KParts::Part* KudesignerFactory::createPartObject( QWidget *parentWidget, const char *widgetName, QObject* parent, const char* name, const char* classname, const QStringList & data )
+KParts::Part* KudesignerFactory::createPartObject( TQWidget *tqparentWidget, const char *widgetName, TQObject* tqparent, const char* name, const char* classname, const TQStringList & data )
{
// If classname is "KoDocument", our host is a koffice application
// otherwise, the host wants us as a simple part, so switch to readonly and single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
- // parentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
- KudesignerDoc *part = new KudesignerDoc( parentWidget, widgetName, parent, name, !bWantKoDocument );
+ // tqparentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
+ KudesignerDoc *part = new KudesignerDoc( tqparentWidget, widgetName, tqparent, name, !bWantKoDocument );
if ( !bWantKoDocument )
part->setReadWrite( false );
if ( bWantKoDocument && ( data.count() > 0 ) )
{
- for ( QStringList::const_iterator it = data.begin();it != data.end();++it )
+ for ( TQStringList::const_iterator it = data.begin();it != data.end();++it )
{
if ( ( *it ).startsWith( "plugin=" ) )
{
@@ -64,7 +64,7 @@ KParts::Part* KudesignerFactory::createPartObject( QWidget *parentWidget, const
}
else if ( ( *it ).startsWith( "forcePropertyEditorPosition=" ) )
{
- QString tmp = ( *it ).right( ( *it ).length() - 28 ).upper();
+ TQString tmp = ( *it ).right( ( *it ).length() - 28 ).upper();
kdDebug() << "forced property editor position: " << tmp << endl;
part->setForcedPropertyEditorPosition( tmp == "LEFT" ? DockLeft : DockRight );
}